//
{
  vykonna cast knihovny pro nstalaci podpurnych aplikaci pro pluginy

  Gord,
  1.0.0

  funkce: InstallTool_MoveDir(srcDir,PluginName:string)
             - zkopiruje cely zdrojovy adresar a poznaci jeho prislusnost k pluginu
          InstallTool_MoveFile(srcFile,PluginName:string)
             - zkopiruje zdrojovy soubor a poznaci jeho prislusnost k pluginu
          InstallTool_RemoveDir(srcDir,PluginName:string)
             - vymaze prislusnost adresare k pluginu a pokud je to posledni plugin, cely adresar odstrani
          InstallTool_RemoveFile(srcFile,PluginName:string)
             - vymaze prislusnost souboru k pluginu a pokud je to posledni plugin, soubor odstrani

  DATADIR\Tools\Content.ini popisuje obsah adresare. Pro kazdy soubor nebo
          podadresar obsahuje zaznam
          <FILE>=<PluginName1,PluginName2,...
          <DIR>=<PluginName1,PluginName2,...
}


const INSTALLTOOL_CONTENT='Content.ini';

function InstallTool_GetToolDir:string;
begin
  Result:=GEOGET_DATADIR+'\Tools\';
end;

function InstallTool_GetContentFilename:string;
begin
  Result:=GEOGET_DATADIR+'\Tools\Content.ini';
end;

procedure InstallTool_Init;
begin
  ForceDirectories(InstallTool_GetToolDir());  //vytvorime adresar
  //pokud neexistuje Content soubor, vytvorime jej
  if(not FileExists(InstallTool_GetContentFilename())) then begin
    StringToFile(
      '; Soubor popisuje obsah adresare a seznam pluginu, ktere jednotlive'+CRLF
     +'; aplikace pouzivaji.'+CRLF+CRLF
     +'; Zaznam ma jeden z formatu:'+CRLF
     +';     <file>=Plugin1 [,Plugin2 [,... [PluninN]]]'+CRLF
     +';     <dir>=Plugin1 [,Plugin2 [,... [PluninN]]]'+CRLF+CRLF
     +'[Files]'+CRLF+CRLF
     +'[Directories]'+CRLF
     ,InstallTool_GetContentFilename());
  end;
end;

//prida polozku do obsahu
procedure InstallTool_AddContent(Section,Name,Plugin:string);
var ini:TIniFile;
    s:string;
begin
  ini:=TIniFile.Create(InstallTool_GetContentFilename());
  try
    s:=ini.ReadString(Section,Name,'');
    //pokud tam jeste plugin neni, zapiseme ho k souboru
    if(s='') then s:=Plugin
    else begin
      s:=' '+s+' ';
      if(not RegexFind('(?i)\W'+Plugin+'\W',s)) then s:=Trim(s)+','+Plugin;
    end;
    ini.WriteString(Section,Name,Trim(s));
  finally
    ini.Free();
  end;
end;

//odstrani polozku z obsahu, pokud je plugin posledni pro zadanou polozku,
//odstrani ji i z disku
procedure InstallTool_RemoveContent(Section,Name,Plugin:string);
var ini:TIniFile;
    s:string;
begin
  ini:=TIniFile.Create(InstallTool_GetContentFilename());
  try
    s:=ini.ReadString(Section,Name,'');
    //pokud tam jeste plugin neni, zapiseme ho k souboru
    s:=' '+s+' ';
    if(RegexFind('(?i)\W'+Plugin+'\W',s)) then begin
      s:=Trim(ReplaceString(RegexSubstitute('(?i)(.*\W)'+Plugin+'\W(.*)',s,'$1$2'),',,',','));
      if(Length(s)<2) then begin
        s:='';
        if(Section='Files') then DeleteFile(InstallTool_GetToolDir()+Name)
        else DelTree(InstallTool_GetToolDir()+Name);
      end;
    end;
    s:=Trim(s);
    if(Length(s)=0) then ini.DeleteKey(Section,Name)
    else ini.WriteString(Section,Name,s);
  finally
    ini.Free();
  end;
end;

//zkopiruje zdrojovy soubor a poznaci jeho prislusnost k pluginu
function InstallTool_MoveFile(srcFile,PluginName:string):boolean;
var sName:string;
begin
  InstallTool_Init();
  sName:=RegexReplace('.*\\',srcFile,'',false);
  Result:=CopyFile(srcFile,InstallTool_GetToolDir()+sName);
  if(not Result) then ShowMessage('ERR:'+CRLF+'srcFile: '+srcFile+CRLF+'trgFile: '+InstallTool_GetToolDir()+sName)
  else begin
    DeleteFile(srcFile);
    InstallTool_AddContent('Files',sName,PluginName);
  end;
end;

//zkopiruje cely zdrojovy adresar a poznaci jeho prislusnost k pluginu
function InstallTool_MoveDir(srcDir,PluginName:string):boolean;
var sName:string;
begin
  InstallTool_Init();
  //pokud je na konci '\', odstranime jej
  if(srcDir[Length(srcDir)-1]='\') then begin
    srcDir[Length(srcDir)-1]:=' ';
    srcDir:=Trim(srcDir);
  end;
  sName:=RegexReplace('.*\\',srcDir,'',false);
  CopyTree(srcDir,InstallTool_GetToolDir()+sName);
  DelTree(srcDir);
  InstallTool_AddContent('Directories',sName,PluginName);
  Result:=true;
end;

//vymaze prislusnost souboru k pluginu a pokud je to posledni plugin, soubor odstrani
function InstallTool_RemoveFile(srcFile,PluginName:string):boolean;
var sName:string;
begin
  InstallTool_Init();
  sName:=RegexReplace('.*\\',srcFile,'',false);
  InstallTool_RemoveContent('Files',sName,PluginName);
  Result:=true;
end;

//vymaze prislusnost adresare k pluginu a pokud je to posledni plugin, cely adresar odstrani
function InstallTool_RemoveDir(srcDir,PluginName:string):boolean;
var sName:string;
begin
  InstallTool_Init();
  //pokud je na konci '\', odstranime jej
  if(srcDir[Length(srcDir)-1]='\') then begin
    srcDir[Length(srcDir)-1]:=' ';
    srcDir:=Trim(srcDir);
  end;
  sName:=RegexReplace('.*\\',srcDir,'',false);
  InstallTool_RemoveContent('Directories',sName,PluginName);
  Result:=true;
end;

